/// Copyright Thomas Nagy 2007
/// License: QPL
#ifndef sznsh
#define sznsh

#include <QColor>
#include "con.h"
#include <QString>

class szn 
<%
	public:
		szn();

		QString kidlgz;
		QColor kitzjl;
		QColor jlzpnt;
		QColor irnyjl;
%>;

#endif

